@@ -24,7 +24,6 @@ from eventsourcing.infrastructure.sequenceditem import (
 from eventsourcing.infrastructure.sequenceditemmapper import AbstractSequencedItemMapper
 from eventsourcing.whitehead import TEvent
 
-
 DEFAULT_PIPELINE_ID = 0
 
 TrackingKwargs = Dict[str, Union[str, int]]
@@ -127,7 +126,7 @@ class BaseRecordManager(AbstractRecordManager):
         record_class: type,
         sequenced_item_class: Type[NamedTuple] = SequencedItem,  # type: ignore
         contiguous_record_ids: bool = False,
-        application_name: str = '',
+        application_name: str = "",
         pipeline_id: int = DEFAULT_PIPELINE_ID,
         **kwargs: Any
     ):
@@ -294,9 +293,7 @@ class RecordManagerWithNotifications(BaseRecordManager):
             yield self.create_notification_from_record(record)
 
     def create_notification_from_record(self, record):
-        notification = {
-            "id": getattr(record, self.notification_id_name)
-        }
+        notification = {"id": getattr(record, self.notification_id_name)}
         for field_name in self.field_names:
             notification[field_name] = getattr(record, field_name)
         if hasattr(record, "causal_dependencies"):
@@ -534,9 +531,7 @@ class AbstractEventStore(ABC, Generic[TEvent, TRecordManager]):
     """
 
     def __init__(
-        self,
-        record_manager: TRecordManager,
-        event_mapper: AbstractSequencedItemMapper,
+        self, record_manager: TRecordManager, event_mapper: AbstractSequencedItemMapper,
     ):
         """
         Initialises event store object.
