@@ -1,5 +1,5 @@
 import uuid
-from typing import Dict, Optional, cast, Generic
+from typing import Dict, Generic, Optional, cast
 from unittest.case import TestCase
 from uuid import UUID
 
@@ -16,8 +16,8 @@ from eventsourcing.infrastructure.sqlalchemy.records import IntegerSequencedNoID
 from eventsourcing.tests.sequenced_item_tests.test_sqlalchemy_record_manager import (
     SQLAlchemyRecordManagerTestCase,
 )
-from eventsourcing.whitehead import TEntity
 from eventsourcing.utils.topic import get_topic, resolve_topic
+from eventsourcing.whitehead import TEntity
 
 
 class TestAggregateRootEvent(TestCase):
@@ -77,31 +77,47 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
         self.assertIn("AttributeChanged", ExampleAggregateRoot.__dict__)
 
         self.assertEqual(ExampleAggregateRoot.Event.__name__, "Event")
-        self.assertEqual(ExampleAggregateRoot.Event.__qualname__, "ExampleAggregateRoot.Event")
+        self.assertEqual(
+            ExampleAggregateRoot.Event.__qualname__, "ExampleAggregateRoot.Event"
+        )
         topic = "eventsourcing.tests.core_tests.test_aggregate_root#ExampleAggregateRoot.Event"
         self.assertEqual(get_topic(ExampleAggregateRoot.Event), topic)
         self.assertEqual(resolve_topic(topic), ExampleAggregateRoot.Event)
 
         self.assertEqual(ExampleAggregateRoot.Created.__name__, "Created")
-        self.assertEqual(ExampleAggregateRoot.Created.__qualname__, "ExampleAggregateRoot.Created")
+        self.assertEqual(
+            ExampleAggregateRoot.Created.__qualname__, "ExampleAggregateRoot.Created"
+        )
         topic = "eventsourcing.tests.core_tests.test_aggregate_root#ExampleAggregateRoot.Created"
         self.assertEqual(get_topic(ExampleAggregateRoot.Created), topic)
         self.assertEqual(resolve_topic(topic), ExampleAggregateRoot.Created)
-        self.assertTrue(issubclass(ExampleAggregateRoot.Created, ExampleAggregateRoot.Event))
+        self.assertTrue(
+            issubclass(ExampleAggregateRoot.Created, ExampleAggregateRoot.Event)
+        )
 
         self.assertEqual(ExampleAggregateRoot.Discarded.__name__, "Discarded")
-        self.assertEqual(ExampleAggregateRoot.Discarded.__qualname__, "ExampleAggregateRoot.Discarded")
+        self.assertEqual(
+            ExampleAggregateRoot.Discarded.__qualname__,
+            "ExampleAggregateRoot.Discarded",
+        )
         topic = "eventsourcing.tests.core_tests.test_aggregate_root#ExampleAggregateRoot.Discarded"
         self.assertEqual(get_topic(ExampleAggregateRoot.Discarded), topic)
         self.assertEqual(resolve_topic(topic), ExampleAggregateRoot.Discarded)
-        self.assertTrue(issubclass(ExampleAggregateRoot.Discarded, ExampleAggregateRoot.Event))
+        self.assertTrue(
+            issubclass(ExampleAggregateRoot.Discarded, ExampleAggregateRoot.Event)
+        )
 
         self.assertEqual(ExampleAggregateRoot.ExampleCreated.__name__, "ExampleCreated")
-        self.assertEqual(ExampleAggregateRoot.ExampleCreated.__qualname__, "ExampleAggregateRoot.ExampleCreated")
+        self.assertEqual(
+            ExampleAggregateRoot.ExampleCreated.__qualname__,
+            "ExampleAggregateRoot.ExampleCreated",
+        )
         topic = "eventsourcing.tests.core_tests.test_aggregate_root#ExampleAggregateRoot.ExampleCreated"
         self.assertEqual(get_topic(ExampleAggregateRoot.ExampleCreated), topic)
         self.assertEqual(resolve_topic(topic), ExampleAggregateRoot.ExampleCreated)
-        self.assertTrue(issubclass(ExampleAggregateRoot.ExampleCreated, ExampleAggregateRoot.Event))
+        self.assertTrue(
+            issubclass(ExampleAggregateRoot.ExampleCreated, ExampleAggregateRoot.Event)
+        )
 
     def test_aggregate1_event_classes(self):
         self.assertIn("Event", Aggregate1.__dict__)
@@ -205,13 +221,13 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
         last_next_hash = aggregate.__head__
 
         # Check it does not exist in the repository.
-        self.assertNotIn(aggregate.id, self.app.aggregate1_repository)
+        self.assertNotIn(aggregate.id, self.app.repository)
 
         # Save the aggregate.
         aggregate.__save__()
 
         # Check it now exists in the repository.
-        self.assertIn(aggregate.id, self.app.aggregate1_repository)
+        self.assertIn(aggregate.id, self.app.repository)
 
         # Change an attribute of the aggregate root entity.
         self.assertNotEqual(aggregate.foo, "bar")
@@ -222,11 +238,11 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
         self.assertNotEqual(aggregate.__head__, last_next_hash)
         last_next_hash = aggregate.__head__
 
-        self.assertIn(aggregate.id, self.app.aggregate1_repository)
+        self.assertIn(aggregate.id, self.app.repository)
 
-        self.assertNotEqual(self.app.aggregate1_repository[aggregate.id].foo, "bar")
+        self.assertNotEqual(self.app.repository[aggregate.id].foo, "bar")
         aggregate.__save__()
-        self.assertEqual(self.app.aggregate1_repository[aggregate.id].foo, "bar")
+        self.assertEqual(self.app.repository[aggregate.id].foo, "bar")
 
         # Check the aggregate has zero entities.
         self.assertEqual(aggregate.count_examples(), 0)
@@ -242,7 +258,7 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
 
         # Check the aggregate in the repo still has zero entities.
         self.assertEqual(
-            self.app.aggregate1_repository[aggregate.id].count_examples(), 0
+            self.app.repository[aggregate.id].count_examples(), 0
         )
 
         # Check the head hash has changed.
@@ -254,7 +270,7 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
 
         # Check the aggregate in the repo now has one entity.
         self.assertEqual(
-            self.app.aggregate1_repository[aggregate.id].count_examples(), 1
+            self.app.repository[aggregate.id].count_examples(), 1
         )
 
         # Create two more entities within the aggregate.
@@ -266,7 +282,7 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
 
         # Check the aggregate in the repo now has three entities.
         self.assertEqual(
-            self.app.aggregate1_repository[aggregate.id].count_examples(), 3
+            self.app.repository[aggregate.id].count_examples(), 3
         )
 
         # Discard the aggregate, calls save().
@@ -277,7 +293,7 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
         self.assertNotEqual(aggregate.__head__, last_next_hash)
 
         # Check the aggregate no longer exists in the repo.
-        self.assertNotIn(aggregate.id, self.app.aggregate1_repository)
+        self.assertNotIn(aggregate.id, self.app.repository)
 
     def test_both_types(self):
         # Create a new aggregate.
@@ -299,8 +315,8 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
         aggregate1.__save__()
         aggregate2.__save__()
 
-        aggregate1 = self.app.aggregate1_repository[aggregate1.id]
-        aggregate2 = self.app.aggregate2_repository[aggregate2.id]
+        aggregate1 = self.app.repository[aggregate1.id]
+        aggregate2 = self.app.repository[aggregate2.id]
 
         self.assertIsInstance(aggregate1, Aggregate1)
         self.assertIsInstance(aggregate2, Aggregate2)
@@ -310,15 +326,8 @@ class TestExampleAggregateRoot(SQLAlchemyRecordManagerTestCase):
 
         aggregate1.__discard__()
         aggregate1.__save__()
-        self.assertFalse(aggregate1.id in self.app.aggregate1_repository)
-        self.assertTrue(aggregate2.id in self.app.aggregate2_repository)
-
-        # Todo: Somehow avoid all IDs existing in all repositories.
-        # - either namespace the UUIDs, with a UUID for each type,
-        #     with adjustments to repository and factory methods.
-        # - or make sequence type be a thing, with IDs being valid within the type
-        #     compound partition key in Cassandra,
-        # self.assertFalse(aggregate2.id in self.app.aggregate1_repository)
+        self.assertFalse(aggregate1.id in self.app.repository)
+        self.assertTrue(aggregate2.id in self.app.repository)
 
     def test_validate_previous_hash_error(self):
         # Check event has valid originator head.
@@ -419,9 +428,7 @@ class ExampleDDDApplication(Generic[TEntity]):
                 position_attr_name="originator_version",
             ),
         )
-        # Todo: Remove having two repositories, because they are identical.
-        self.aggregate1_repository = AggregateRepository(event_store=event_store)
-        self.aggregate2_repository = AggregateRepository(event_store=event_store)
+        self.repository = EventSourcedRepository(event_store=event_store)
         self.persistence_policy = PersistencePolicy(
             persist_event_type=ExampleAggregateRoot.Event, event_store=event_store
         )
@@ -433,14 +440,14 @@ class ExampleDDDApplication(Generic[TEntity]):
         a: Aggregate1 = Aggregate1.__create__()
         return a
 
-    def create_aggregate2(self)-> Aggregate2:
+    def create_aggregate2(self) -> Aggregate2:
         """
         Factory method, creates and returns a new aggregate1 root entity.
         """
         a: Aggregate2 = Aggregate2.__create__()
         return a
 
-    def create_aggregate3(self)-> Aggregate3:
+    def create_aggregate3(self) -> Aggregate3:
         """
         Factory method, creates and returns a new aggregate1 root entity.
         """
