@@ -1,9 +1,9 @@
 from unittest import skip
 
+from eventsourcing.application.django import DjangoApplication
 from eventsourcing.tests.sequenced_item_tests.test_django_record_manager import (
     DjangoTestCase,
 )
-from eventsourcing.application.django import DjangoApplication
 from eventsourcing.tests.test_ray_runner import TestRayRunner
 
 
@@ -13,4 +13,4 @@ class DontTestRayRunnerWithDjango(DjangoTestCase, TestRayRunner):
 
 
 # Don't let this be found here.
-del(TestRayRunner)
+del TestRayRunner
